@@ -68,6 +68,14 @@ function init_banner() {
     }
 
     text += "<b id='_wb_capture_info'>" + capture_str + "</b>";
+
+    if (wbinfo.proxy_magic && wbinfo.url) {
+        var select_url = wbinfo.proxy_magic + "/" + wbinfo.url;
+        var query_url = wbinfo.proxy_magic + "/*/" + wbinfo.url;
+        text += '&nbsp;<a href="//query.' + query_url + '">All Capture Times</a>';
+        text += '<br/>'
+        text += 'From collection <b>"' + wbinfo.coll + '"</b>&nbsp;<a href="//select.' + select_url + '">All Collections</a>';
+    }
     
     banner.innerHTML = text;
 
