@@ -219,16 +219,17 @@ class TestWb:
         assert '/pywb/20140127171251mp_/http://www.iana.org/domains/example' in resp.body
 
     def test_redirect_relative_3(self):
+        # webtest uses Host: localhost:80 by default
         # first two requests should result in same redirect
-        target = 'http://localhost:8080/pywb/2014mp_/http://iana.org/_css/2013.1/screen.css'
+        target = 'http://localhost:80/pywb/2014mp_/http://iana.org/_css/2013.1/screen.css'
 
         # without timestamp
-        resp = self.testapp.get('/_css/2013.1/screen.css', headers = [('Referer', 'http://localhost:8080/pywb/2014mp_/http://iana.org/')])
+        resp = self.testapp.get('/_css/2013.1/screen.css', headers = [('Referer', 'http://localhost:80/pywb/2014mp_/http://iana.org/')])
         assert resp.status_int == 302
         assert resp.headers['Location'] == target, resp.headers['Location']
 
         # with timestamp
-        resp = self.testapp.get('/2014/_css/2013.1/screen.css', headers = [('Referer', 'http://localhost:8080/pywb/2014mp_/http://iana.org/')])
+        resp = self.testapp.get('/2014/_css/2013.1/screen.css', headers = [('Referer', 'http://localhost:80/pywb/2014mp_/http://iana.org/')])
         assert resp.status_int == 302
         assert resp.headers['Location'] == target, resp.headers['Location']
 
@@ -313,7 +314,7 @@ class TestWb:
 
     def test_post_redirect(self):
         # post handled without redirect (since 307 not allowed)
-        resp = self.testapp.post('/post', {'foo': 'bar', 'test': 'abc'}, headers=[('Referer', 'http://localhost:8080/pywb/2014mp_/http://httpbin.org/post')])
+        resp = self.testapp.post('/post', {'foo': 'bar', 'test': 'abc'}, headers=[('Referer', 'http://localhost:80/pywb/2014mp_/http://httpbin.org/post')])
         assert resp.status_int == 200
         assert '"foo": "bar"' in resp.body
         assert '"test": "abc"' in resp.body
@@ -340,65 +341,6 @@ class TestWb:
         resp = self.testapp.get('/static/test/route/notfound.css', status = 404)
         assert resp.status_int == 404
 
-    # 'Simulating' proxy by settings REQUEST_URI explicitly to http:// url and no SCRIPT_NAME
-    # would be nice to be able to test proxy more
-    def test_proxy_replay(self):
-        resp = self.testapp.get('/x-ignore-this-x', extra_environ = dict(REQUEST_URI = 'http://www.iana.org/domains/idn-tables', SCRIPT_NAME = ''))
-        self._assert_basic_html(resp)
-
-        assert '"20140126201127"' in resp.body
-        assert 'wb.js' in resp.body
-
-    def test_proxy_replay_auth_filtered(self):
-        headers = [('Proxy-Authorization', 'Basic ' + base64.b64encode('pywb-filt-2:'))]
-        resp = self.testapp.get('/x-ignore-this-x', headers = headers,
-                                extra_environ = dict(REQUEST_URI = 'http://www.iana.org/', SCRIPT_NAME = ''))
-
-        self._assert_basic_html(resp)
-
-        assert '"20140126200624"' in resp.body
-        assert 'wb.js' in resp.body
-
-    def test_proxy_replay_auth(self):
-        headers = [('Proxy-Authorization', 'Basic ' + base64.b64encode('pywb'))]
-        resp = self.testapp.get('/x-ignore-this-x', headers = headers,
-                                extra_environ = dict(REQUEST_URI = 'http://www.iana.org/', SCRIPT_NAME = ''))
-
-        self._assert_basic_html(resp)
-
-        assert '"20140127171238"' in resp.body
-        assert 'wb.js' in resp.body
-
-    def test_proxy_replay_auth_no_coll(self):
-        headers = [('Proxy-Authorization', 'Basic ' + base64.b64encode('no-such-coll'))]
-        resp = self.testapp.get('/x-ignore-this-x', headers = headers,
-                                extra_environ = dict(REQUEST_URI = 'http://www.iana.org/', SCRIPT_NAME = ''),
-                                status=407)
-
-        assert resp.status_int == 407
-
-    def test_proxy_replay_auth_invalid_1(self):
-        headers = [('Proxy-Authorization', 'abc' + base64.b64encode('no-such-coll'))]
-        resp = self.testapp.get('/x-ignore-this-x', headers = headers,
-                                extra_environ = dict(REQUEST_URI = 'http://www.iana.org/', SCRIPT_NAME = ''),
-                                status=407)
-
-        assert resp.status_int == 407
-
-    def test_proxy_replay_auth_invalid_2(self):
-        headers = [('Proxy-Authorization', 'basic')]
-        resp = self.testapp.get('/x-ignore-this-x', headers = headers,
-                                extra_environ = dict(REQUEST_URI = 'http://www.iana.org/', SCRIPT_NAME = ''),
-                                status=407)
-
-        assert resp.status_int == 407
-
-    def test_proxy_pac(self):
-        resp = self.testapp.get('/proxy.pac', extra_environ = dict(SERVER_NAME='pywb-proxy', SERVER_PORT='8080'))
-        assert resp.content_type == 'application/x-ns-proxy-autoconfig'
-        assert '"PROXY pywb-proxy:8080"' in resp.body
-        assert '"localhost"' in resp.body
-
     def test_cdx_server_filters(self):
         resp = self.testapp.get('/pywb-cdx?url=http://www.iana.org/_css/2013.1/screen.css&filter=mimetype:warc/revisit&filter=filename:dupes.warc.gz')
         self._assert_basic_text(resp)
